=============================
Quick Menu (:mod:`quickmenu`)
=============================

.. automodule:: orangecanvas.document.quickmenu


.. autoclass:: QuickMenu
   :members:
   :exclude-members:
      triggered,
      hovered
   :member-order: bysource
   :show-inheritance:

   .. automethod:: triggered(QAction)

   .. automethod:: hovered(QAction)


.. autoclass:: MenuPage
   :members:
   :exclude-members:
      title_,
      icon_
   :member-order: bysource
   :show-inheritance:
